@@ -1,10 +1,11 @@
 require "rails-assets-jquery-placeholder/version"
 
+require "rails-assets-jquery"
 
 module RailsAssetsJqueryPlaceholder
 
   def self.gem_path
-    Pathname(__FILE__).join('../..')
+    Pathname(File.realpath(__FILE__)).join('../..')
   end
 
   def self.gem_spec
@@ -19,7 +20,7 @@ module RailsAssetsJqueryPlaceholder
 
   def self.dependencies
     [
-      
+      RailsAssetsJquery
     ]
   end
 
